# BEGIN COPYRIGHT
# *************************************************************************
# Licensed Materials - Property of IBM
# 5724-L01, 5655-N53, 5724-I82, 5655-R15
# (C) Copyright IBM Corporation 2008, 2009. All rights reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
# *************************************************************************
# END COPYRIGHT

from java.lang import System
import sys

# Utility to handle list
def wsadminToList(inStr):
        outList=[]
        if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
                tmpList = inStr[1:-1].split() #splits space-separated lists,
        else:
                tmpList = inStr.split("\n")   #splits for Windows or Linux
        for item in tmpList:
                item = item.rstrip();         #removes any Windows "\r"
                if (len(item)>0):
                        outList.append(item)
        return outList
#endDef

# Update Application
def updateApp(attr,applicationName):

        print str(attr);
        print applicationName;
        AdminApp.update(applicationName, 'app', attr)
        AdminConfig.save( )
        print applicationName+" is updated successfully"
#enddef

def prepareAndUpdateApp(appName, attrs, nodeNames, clusterName):

  deployment = AdminConfig.getid("/Deployment:" + appName + "/")
  if deployment == None or deployment == "":
    print appName + " not installed, skipping"
    return
  #endif
   
  for target in wsadminToList(AdminConfig.showAttribute(deployment, "deploymentTargets")):
    nlist = AdminConfig.show(target).split("\n")
    ndict = {}
    for i in range(len(nlist)):
      key, value = wsadminToList(nlist[i].rstrip())
      ndict[key] = value
    #endfor
    if clusterName:
      print "INFO: clusterName = " + clusterName + "."
      if not ndict.has_key("nodeName") and clusterName == ndict["name"]:
        print "INFO: update " + appName + " on cluster " + clusterName + "."
        updateAttrs = attrs
        updateAttrs.extend(["-cluster", clusterName])
        print "INFO: updateAttrs = " + str(updateAttrs)
        updateApp(updateAttrs, appName)
      #endif
    else:
      print "INFO: No cluster."
      if ndict.has_key("nodeName") and ndict["nodeName"] in nodeNames:
        node = AdminConfig.getid("/Cell:" + System.getProperty("local.cell") + "/Node:" + ndict["nodeName"] + "/")
        for server in wsadminToList(AdminConfig.list("Server", node)):
          serverName = AdminConfig.showAttribute(server, "name")
          if serverName == ndict["name"]:
            print "update " + appName + " on node " + ndict["nodeName"] + ", server " + serverName + "."
            updateAttrs = attrs
            updateAttrs.extend(["-node", ndict["nodeName"], "-server", serverName])
            print "INFO: updateAttrs = " + str(updateAttrs)
            updateApp(updateAttrs, appName)
          #endif
        #endfor
      #endif
    #endif
  #endfor

#enddef

################
#     MAIN     #
################

clusterName = System.getProperty("wbi.upgrade.cluster.name")
if clusterName == "":
  clusterName = None
#endif

nodeNames = None

if not clusterName:
  nodeNames = [ System.getProperty("local.node") ]
  managedNodes = System.getProperty("wbi.upgrade.managed.nodes")
  if managedNodes and managedNodes != "" and managedNodes != "{}":
    nodeNames.append(managedNodes.split(" "))
  #endif
#endif

print "INFO:  BSpaceManager Application properties"
earLoc1 =  System.getProperty("was.install.root") + "/installableApps/BSpaceManager.ear";
mgrAttrs = ["-operation", "update", "-contents", earLoc1]
print earLoc1;
print str(mgrAttrs);

print "INFO:  BSpaceWidgets Application properties"
earLoc2 = System.getProperty("was.install.root") + "/installableApps/BSpaceWidgets.ear";
warAppNames = "IBM_BSPACE_WIDGETS_COMMON"
warNames = "BSpaceWidgetsCommon"
warAppNameList=warAppNames.split(',')
warNameList=warNames.split(',')
mapWebModOptStr='-MapWebModToVH ['

for i in range(len(warAppNameList)):
	mapWebModOptStr += '[ "'+warAppNameList[i]+'" '+warNameList[i]+'.war,WEB-INF/web.xml default_host ]'

mapWebModOptStr +=']';
print "INFO:  mapWebModOptStr="+str(mapWebModOptStr)
widgetAttrs = ["-operation", "update", "-contents", earLoc2, mapWebModOptStr];
print earLoc2;
print str(widgetAttrs);

print "INFO:  Updating BSpaceManager Application"
prepareAndUpdateApp('BusinessSpaceManager', mgrAttrs, nodeNames, clusterName)

print "INFO:  Updating BSpaceWidgets Application"
prepareAndUpdateApp('IBM_BSPACE_WIDGETS', widgetAttrs, nodeNames, clusterName)
