-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2008, 2009.  All Rights Reserved.
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
----------------------------------------------------------------------
--
-- Script file to perform schema changes for Business Space during
-- migration from 6.1.2 to 6.2
--
-- Customize the following variables before running this script:
--   @STOGRP@ = DB2 Storage group name
--   @DBNAME@ = DB2 Database name
--   @SCHEMA@ = DB2 Schema qualifier
--
-- BP8K0, BP16K0, and BP32 may require Grants as well as tailoring
-- BufferPool Names
-- Storage Group may require Grants 
--

---------------------------------
-- Create, modify, drop tables --
---------------------------------

CREATE TABLESPACE BSPACEC
  IN @DBNAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  DEFINE NO
  LOCKSIZE ANY
  BUFFERPOOL BP8K0
  CCSID UNICODE;

CREATE TABLESPACE BSPACED
  IN @DBNAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  DEFINE NO
  LOCKSIZE ANY
  CCSID UNICODE;

----------------------------------------------------------------------

CREATE LOB TABLESPACE BSBLOB13
 IN @DBNAME@
 USING STOGROUP @STOGRP@
 LOCKSIZE LOB
 BUFFERPOOL BP3;

CREATE LOB TABLESPACE BSBLOB14
 IN @DBNAME@
 USING STOGROUP @STOGRP@
 LOCKSIZE LOB
 BUFFERPOOL BP3;

----------------------------------------------------------------------

	DROP TABLE @SCHEMA@.DASHBOARD_DATA_T;
	-- Also dropped by above: DASHBOARD_DATA_P, BSBLOB1_T, BSBLOB1_I.

	DROP TABLESPACE @DBNAME@.BSPACE1;

	DROP TABLESPACE @DBNAME@.BSBLOB1;

----------------------------------------------------------------------

-- No change to the USER_DATA_T table
-- No change to the SPACES table
-- No change to the NLSINFO table

	CREATE INDEX @SCHEMA@.I0000010 ON @SCHEMA@.PAGE ( OWNER ASC )
		USING STOGROUP @STOGRP@
			DEFINE NO
			BUFFERPOOL BP2
			NOT PADDED;	

	CREATE INDEX @SCHEMA@.I0000011 ON @SCHEMA@.PAGE ( SPACEID ASC )
		USING STOGROUP @STOGRP@
			DEFINE NO
			BUFFERPOOL BP2
			NOT PADDED;

-- No change to the WIDGET table
-- No change to the REGISTERED_WIDGET table
-- No change to the REGISTERED_WIDGET_NLS table
-- No change to the REGISTERED_CATEGORY table
-- No change to the REGISTERED_CATEGORY_NLS table

	ALTER TABLE @SCHEMA@.REGISTERED_ENDPOINT
			ADD COLUMN TYPE         VARCHAR(256) ;
	ALTER TABLE @SCHEMA@.REGISTERED_ENDPOINT
			ADD COLUMN NAME         VARCHAR(256) ;
	
	CREATE TABLE @SCHEMA@.REGISTERED_ENDPOINT_NLS  (
			  EXTENSION 			BLOB(10K) ,
		      ID_LOCALE 			VARCHAR(356) NOT NULL ,
			  ENDPOINT_ID_VERSION 	VARCHAR(322) NOT NULL ,
			  LOCALE 				VARCHAR(32) ,
			  NAME 					VARCHAR(256) ,
			  DESCRIPTION 			VARCHAR(1024) ,
			  PRIMARY KEY ( ID_LOCALE ) ,
			  FOREIGN KEY ( ENDPOINT_ID_VERSION )
				REFERENCES @SCHEMA@.REGISTERED_ENDPOINT ( ID_VERSION )
				ON DELETE CASCADE )
			 IN @DBNAME@.BSPACEC ;
			 
	-- auxiliary table for BLOB column EXTENSION
	CREATE AUX TABLE @SCHEMA@.BSBLOB13_T
   	IN @DBNAME@.BSBLOB13
   	STORES @SCHEMA@.REGISTERED_ENDPOINT_NLS COLUMN
 	EXTENSION;
	-- auxiliary index for BLOB column EXTENSION
	CREATE UNIQUE INDEX @SCHEMA@.BSBLOB13_I
	  ON @SCHEMA@.BSBLOB13_T
	   USING STOGROUP @STOGRP@
              BUFFERPOOL BP2;
			 
	CREATE UNIQUE INDEX
  	@SCHEMA@.REGISTERED_ENDPOINT_NLS_P ON
  	@SCHEMA@.REGISTERED_ENDPOINT_NLS
	( 
  	ID_LOCALE
	) 
	USING STOGROUP @STOGRP@
              DEFINE NO
              BUFFERPOOL BP2
              NOT PADDED;
	
	CREATE TABLE @SCHEMA@.REGISTERED_WCCM_ENDPOINT (
			  EXTENSION 		BLOB(10K) ,
			  ID_VERSION 		VARCHAR(322) NOT NULL ,
			  LAST_CHANGE 		VARCHAR(32) NOT NULL ,
			  PRIMARY KEY ( ID_VERSION ) )
			 IN @DBNAME@.BSPACED ;
			 
	-- auxiliary table for BLOB column EXTENSION
	CREATE AUX TABLE @SCHEMA@.BSBLOB14_T
   	IN @DBNAME@.BSBLOB14
   	STORES @SCHEMA@.REGISTERED_WCCM_ENDPOINT COLUMN
 	EXTENSION;
	-- auxiliary index for BLOB column EXTENSION
	CREATE UNIQUE INDEX @SCHEMA@.BSBLOB14_I
	  ON @SCHEMA@.BSBLOB14_T
	   USING STOGROUP @STOGRP@
              BUFFERPOOL BP2;
			 
	CREATE UNIQUE INDEX
  	@SCHEMA@.REGISTERED_WCCM_ENDPOINT_P ON
  	@SCHEMA@.REGISTERED_WCCM_ENDPOINT
	( 
  	ID_VERSION
	) 
	USING STOGROUP @STOGRP@
              DEFINE NO
              BUFFERPOOL BP2
              NOT PADDED;
	
-- No change to the REGISTRY_FILE table
