-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2007, 2009.  All Rights Reserved.
-- US Government Users Restricted Rights - Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- ------------------------------------------------------------------------------------
--
-- Script file to create tables for Business Space 6.2
--
-- Customize the following variables before running this script: 
--   @SCHEMA@ = the schema owner, e.g. IBMBUSSP
--   @DBPASS@ = the schema owner password
--   @TSDIR@ = the directory or prefix for tablespace datafiles, e.g. DEFAULTTS
--
-- Run the script in SQL*Plus.
-- Example:
--    sqlplus system/passw0rd@orcl @createTable_BusinessSpace.sql  
-- ------------------------------------------------------------------------------------

------------------------
-- Create tablespaces --
------------------------
CREATE TABLESPACE BSPACE
  DATAFILE '@TSDIR@_BSPACE.dbf' SIZE 500M AUTOEXTEND ON NEXT 100M MAXSIZE UNLIMITED LOGGING;

-- CREATE TABLESPACE DMSTS  DATAFILE '@TSDIR@_DMSTS.dbf' SIZE 100M AUTOEXTEND ON NEXT 20M MAXSIZE UNLIMITED LOGGING;

-- CREATE TABLESPACE INDEXTS  DATAFILE '@TSDIR@_INDEXTS.dbf' SIZE 250M AUTOEXTEND ON NEXT 50M MAXSIZE UNLIMITED LOGGING;

-- CREATE TABLESPACE LOBTS  DATAFILE '@TSDIR@_LOBTS.dbf' SIZE 200M AUTOEXTEND ON NEXT 40M MAXSIZE UNLIMITED LOGGING;

-------------------------
-- Create schema owner --
-------------------------
CREATE USER @SCHEMA@ IDENTIFIED BY @DBPASS@;

ALTER USER @SCHEMA@ QUOTA UNLIMITED ON BSPACE;
GRANT CONNECT TO @SCHEMA@;

-------------------
-- Create tables --
-------------------

	CREATE TABLE @SCHEMA@.USER_DATA_T (
		  USER_ID                 VARCHAR2(128) NOT NULL ,
		  USER_CONFIG             VARCHAR2(4000) ,
		  IS_SUPER_USER           VARCHAR2(1) ,
		  EXTENSION               BLOB ,
		  PRIMARY KEY ( USER_ID )
		) TABLESPACE BSPACE
		LOGGING;
	
	CREATE TABLE @SCHEMA@.SPACES (
		  ID                      VARCHAR2(64) NOT NULL ,
		  NAME                    VARCHAR2(128) NOT NULL ,
		  DESCRIPTION             VARCHAR2(512) ,
		  OWNER                   VARCHAR2(256) NOT NULL ,
		  USERS                   VARCHAR2(4000) ,
		  EDITORS                 VARCHAR2(4000) ,
		  THEMES                  VARCHAR2(128) ,
		  ISLOCALIZED             VARCHAR2(1) ,
		  TEMPLATE                VARCHAR2(1) NOT NULL ,
		  EXTENSION               BLOB ,
		  PRIMARY KEY ( ID )
		) TABLESPACE BSPACE
		LOGGING;
	
	CREATE TABLE @SCHEMA@.NLSINFO (
		  EXTENSION               BLOB ,
		  ID                      VARCHAR2(64) NOT NULL ,
		  LOCALENAME              VARCHAR2(64) NOT NULL ,
		  DESCRIPTION             VARCHAR2(512) ,
		  NAME                    VARCHAR2(128) NOT NULL ,
		  PRIMARY KEY ( ID, LOCALENAME )
		) TABLESPACE BSPACE
		LOGGING;
	
	CREATE TABLE @SCHEMA@.PAGE (
		  ID                      VARCHAR2(64) NOT NULL ,
		  SPACEID                 VARCHAR2(64) NOT NULL ,
		  NAME                    VARCHAR2(128) NOT NULL ,
		  DESCRIPTION             VARCHAR2(512) ,
		  OWNER                   VARCHAR2(256) NOT NULL ,
		  USERS                   VARCHAR2(4000) ,
		  EDITORS                 VARCHAR2(4000) ,
		  LAYOUT                  VARCHAR2(128) ,
		  WIDGETS                 VARCHAR2(4000) ,
		  ISLOCALIZED             VARCHAR2(1) ,
		  RESTRICTED              VARCHAR2(1) ,
		  TEMPLATE                VARCHAR2(1) NOT NULL ,
		  EXTENSION               BLOB ,
		  PRIMARY KEY ( ID ) ,
		  FOREIGN KEY ( SPACEID )
			REFERENCES @SCHEMA@.SPACES ( ID )
		) TABLESPACE BSPACE
		LOGGING;
	
	CREATE INDEX @SCHEMA@.I0000010 ON @SCHEMA@.PAGE ( OWNER ASC )
		TABLESPACE BSPACE;
	CREATE INDEX @SCHEMA@.I0000011 ON @SCHEMA@.PAGE ( SPACEID ASC )
		TABLESPACE BSPACE;
	
	CREATE TABLE @SCHEMA@.WIDGET (
		  ID                      VARCHAR2(128) NOT NULL ,
		  NAME                    VARCHAR2(128) ,
		  DEFINITIONID            VARCHAR2(128) NOT NULL ,
		  STATE                   VARCHAR2(32) ,
		  ISLOCALIZED             VARCHAR2(1) ,
		  PREFERENCES             BLOB ,
		  PRIMARY KEY ( ID )
		) TABLESPACE BSPACE
		LOGGING;
	
	CREATE TABLE @SCHEMA@.REGISTERED_WIDGET (
		  EXTENSION               BLOB ,
		  ID_VERSION              VARCHAR2(322) NOT NULL ,
		  ID                      VARCHAR2(256) NOT NULL ,
		  VERSION                 VARCHAR2(64) ,
		  TYPE                    VARCHAR2(32) NOT NULL ,
		  NAME                    VARCHAR2(256) ,
		  DESCRIPTION             VARCHAR2(1024) ,
		  TOOLTIP                 VARCHAR2(512) ,
		  HELP_URL                VARCHAR2(512) ,
		  ICON_URL                VARCHAR2(512) ,
		  PREVIEW_URL             VARCHAR2(512) ,
		  PREVIEW_THUMBNAIL_URL   VARCHAR2(512) ,
		  OWNER                   VARCHAR2(256) ,
		  EMAIL                   VARCHAR2(256) ,
		  SERVICE_ENDPOINTS       VARCHAR2(4000) ,
		  WIDGET_ENDPOINT_ID      VARCHAR2(389) ,
		  WIDGET_URL              VARCHAR2(512) ,
		  VIEW_URL                VARCHAR2(512) ,
		  EDIT_URL                VARCHAR2(512) ,
		  ATTACHABLE              VARCHAR2(8) ,
		  ATTACHMENT_URL          VARCHAR2(512) ,
		  CATEGORY_ID             VARCHAR2(256) NOT NULL ,
		  LAST_CHANGE             TIMESTAMP NOT NULL ,
		  PRIMARY KEY ( ID_VERSION )
		) TABLESPACE BSPACE
		LOGGING;
	
	CREATE TABLE @SCHEMA@.REGISTERED_WIDGET_NLS (
		  EXTENSION               BLOB ,
		  ID_LOCALE               VARCHAR2(356) NOT NULL ,
		  WIDGET_ID_VERSION       VARCHAR2(322) ,
		  LOCALE                  VARCHAR2(32) ,
		  NAME                    VARCHAR2(256) ,
		  DESCRIPTION             VARCHAR2(1024) ,
		  TOOLTIP                 VARCHAR2(512) ,
		  HELP_URL                VARCHAR2(512) ,
		  ICON_URL                VARCHAR2(512) ,
		  PREVIEW_URL             VARCHAR2(512) ,
		  PREVIEW_THUMBNAIL_URL   VARCHAR2(512) ,
		  OWNER                   VARCHAR2(256) ,
		  EMAIL                   VARCHAR2(256) ,
		  PRIMARY KEY ( ID_LOCALE ) ,
		  FOREIGN KEY ( WIDGET_ID_VERSION )
			REFERENCES @SCHEMA@.REGISTERED_WIDGET ( ID_VERSION )
		    ON DELETE CASCADE
		) TABLESPACE BSPACE
		LOGGING;
	
	CREATE TABLE @SCHEMA@.REGISTERED_CATEGORY (
		  EXTENSION               BLOB ,
		  ID                      VARCHAR2(256) NOT NULL ,
		  ORDERING                NUMBER(3) ,
		  NAME                    VARCHAR2(256) ,
		  DESCRIPTION             VARCHAR2(1024) ,
		  TOOLTIP                 VARCHAR2(512) ,
		  LAST_CHANGE             TIMESTAMP NOT NULL ,
		  PRIMARY KEY ( ID )
		) TABLESPACE BSPACE
		LOGGING;
	
	CREATE TABLE @SCHEMA@.REGISTERED_CATEGORY_NLS (
		  EXTENSION               BLOB ,
		  ID_LOCALE               VARCHAR2(290) NOT NULL ,
		  CATEGORY_ID             VARCHAR2(256) NOT NULL ,
		  LOCALE                  VARCHAR2(32) ,
		  NAME                    VARCHAR2(256) ,
		  DESCRIPTION             VARCHAR2(1024) ,
		  TOOLTIP                 VARCHAR2(512) ,
		  PRIMARY KEY ( ID_LOCALE ) ,
		  FOREIGN KEY ( CATEGORY_ID )
			REFERENCES @SCHEMA@.REGISTERED_CATEGORY ( ID )
			ON DELETE CASCADE
		) TABLESPACE BSPACE
		LOGGING;
	
	CREATE TABLE @SCHEMA@.REGISTERED_ENDPOINT (
		  EXTENSION               BLOB ,
		  ID_VERSION              VARCHAR2(322) NOT NULL ,
		  ID                      VARCHAR2(256) NOT NULL ,
		  TYPE                    VARCHAR2(256) ,
		  VERSION                 VARCHAR2(64) ,
		  URL                     VARCHAR2(512) NOT NULL ,
		  NAME                    VARCHAR2(256) ,
		  DESCRIPTION             VARCHAR2(1024) ,
		  LAST_CHANGE             TIMESTAMP NOT NULL ,
		  PRIMARY KEY ( ID_VERSION )
		) TABLESPACE BSPACE
		LOGGING;
	
	CREATE TABLE @SCHEMA@.REGISTERED_ENDPOINT_NLS (
		  EXTENSION               BLOB ,
		  ID_LOCALE               VARCHAR2(356) NOT NULL ,
		  ENDPOINT_ID_VERSION     VARCHAR2(322) NOT NULL ,
		  LOCALE                  VARCHAR2(32) ,
		  NAME                    VARCHAR2(256) ,
		  DESCRIPTION             VARCHAR2(1024) ,
		  PRIMARY KEY ( ID_LOCALE ) ,
		  FOREIGN KEY ( ENDPOINT_ID_VERSION )
			REFERENCES @SCHEMA@.REGISTERED_ENDPOINT ( ID_VERSION )
			ON DELETE CASCADE
		) TABLESPACE BSPACE
		LOGGING;
	
	CREATE TABLE @SCHEMA@.REGISTERED_WCCM_ENDPOINT (
		  EXTENSION               BLOB ,
		  ID_VERSION              VARCHAR2(322) NOT NULL ,
		  LAST_CHANGE             VARCHAR2(32) NOT NULL ,
		  PRIMARY KEY ( ID_VERSION )
		) TABLESPACE BSPACE
		LOGGING;
	
	CREATE TABLE @SCHEMA@.REGISTRY_FILE (
		  EXTENSION               BLOB ,
		  FILEPATH_HOST           VARCHAR2(770) NOT NULL ,
		  FILEPATH                VARCHAR2(512) NOT NULL ,
		  FILE_TIMESTAMP          NUMBER(38) NOT NULL ,
		  HOST_NAME               VARCHAR2(256) NOT NULL ,
		  PRIMARY KEY ( FILEPATH_HOST )
		) TABLESPACE BSPACE
		LOGGING;
	
GRANT SELECT,INSERT,UPDATE,DELETE ON @SCHEMA@.USER_DATA_T TO @SCHEMA@;
GRANT SELECT,INSERT,UPDATE,DELETE ON @SCHEMA@.SPACES TO @SCHEMA@;
GRANT SELECT,INSERT,UPDATE,DELETE ON @SCHEMA@.NLSINFO TO @SCHEMA@;
GRANT SELECT,INSERT,UPDATE,DELETE ON @SCHEMA@.PAGE TO @SCHEMA@;
GRANT SELECT,INSERT,UPDATE,DELETE ON @SCHEMA@.WIDGET TO @SCHEMA@;
GRANT SELECT,INSERT,UPDATE,DELETE ON @SCHEMA@.REGISTERED_WIDGET TO @SCHEMA@;
GRANT SELECT,INSERT,UPDATE,DELETE ON @SCHEMA@.REGISTERED_WIDGET_NLS TO @SCHEMA@;
GRANT SELECT,INSERT,UPDATE,DELETE ON @SCHEMA@.REGISTERED_CATEGORY TO @SCHEMA@;
GRANT SELECT,INSERT,UPDATE,DELETE ON @SCHEMA@.REGISTERED_CATEGORY_NLS TO @SCHEMA@;
GRANT SELECT,INSERT,UPDATE,DELETE ON @SCHEMA@.REGISTERED_ENDPOINT TO @SCHEMA@;
GRANT SELECT,INSERT,UPDATE,DELETE ON @SCHEMA@.REGISTERED_ENDPOINT_NLS TO @SCHEMA@;
GRANT SELECT,INSERT,UPDATE,DELETE ON @SCHEMA@.REGISTERED_WCCM_ENDPOINT TO @SCHEMA@;
GRANT SELECT,INSERT,UPDATE,DELETE ON @SCHEMA@.REGISTRY_FILE TO @SCHEMA@;
	